library insta_html_parser;

import 'package:html/parser.dart';
import 'package:http/http.dart';

class InstaParser { 

  /// Returns the first 12 posts of a public Instagram profile
  static Future<List<String>> parsePostsUrlsFromInstaProfile(String profileUrl) async {
    //print('[InstaParser] [ParsePostsUrlsFromInstaProfile] START profileUrl: $profileUrl');

    if (profileUrl == null) return [];

    String _profilePageData;
    String _temporaryProfileData;
    List<String> _postsUrls = List<String>();
    Client _client = Client();
    Response _response;
    var _elements;
    var _document;

    try{
      _response = await _client.get('$profileUrl');
      _document = parse(_response.body);
      _elements = _document.querySelectorAll('body');
    } catch(error) { print('[InstaParser] [ParsePostsUrlsFromInstaProfile] ERROR: $error'); }

    _profilePageData = _elements[0].text;

    // Step 2 - Get postsUrl (shortcode tag)
    _temporaryProfileData = _profilePageData;
    for (int i = 0; i < 15; i++) {  

      int _inx;
      int _urlLenght;
      String _postUrl;

      _postsUrls.add('');
      _inx = _temporaryProfileData.indexOf("shortcode\":\"");
      _urlLenght = 11; //ex: BxFcM54hJMb  
      _inx += "shortcode\":\"".length; // Advance   
      _postUrl = _temporaryProfileData.substring(_inx).substring(0, _urlLenght); // Gets the postUrl  
      _postsUrls[i] = "https://www.instagram.com/p/$_postUrl"; // Adds to the postsUrls list
      _temporaryProfileData = _temporaryProfileData.substring(_inx); // Cuts the read shortcode

      //print('[InstaParser] [ParsePostsUrlsFromInstaProfile] #$i _postUrl: ${_postsUrls[i]}');
    }
    return _postsUrls;
  }

  /// Returns the video url of a post if it exists or empry string if it hasn't
  static Future<String> parseVideoUrlFromInstaPost(String postUrl) async {

    String _profilePageData;
    String _temporaryProfileData;
    String _videoUrl = '';
    List<String> _videosUrls = [];
    Client _client = Client();
    Response _response;
    var _elements;
    int _endInx;

    try{
      _response = await _client.get('$postUrl');
      var _document = parse(_response.body);
      _elements = _document.querySelectorAll('body');
    } catch(error) { print('[InstaParser] [ParseVideoUrlFromInstaPost] ERROR: $error'); }

    _profilePageData = _elements[0].text;

    // Step 2 - Get videoUrl (video_url tag)
    _temporaryProfileData = _profilePageData;
    _endInx = _temporaryProfileData.indexOf("mp4?_nc_ht=scontent.cdninstagram.com");

    if (_endInx > -1) { // If found
      int _startInx;
      _endInx += "mp4?_nc_ht=scontent.cdninstagram.com".length; // Advance
      _startInx = _temporaryProfileData.indexOf("video_url\":\""); //Search
      _startInx += "video_url\":\"".length; // Advance
      _videoUrl = _temporaryProfileData.substring(_startInx).substring(0, _endInx - _startInx); // Gets the videoUrl
      _videosUrls.add(_videoUrl);  // Adds to the postsUrl list 
      _temporaryProfileData = _temporaryProfileData.substring(_startInx); // Cuts the read src
    } //print('[ReportsPage] [ParseVideoUrlFromInstaPost] _videoUrl: $_videoUrl');

    return _videoUrl;
  }

  /// Returns photos urls for `small`, `medium` and `large` size
  static Future<Map<String, String>> parsePhotosUrlsFromInstaPost(String postUrl) async {
    Map<String, String> _photosAllSizes = Map<String,String>();
    
    if (postUrl[postUrl.length-1] == '/') {
      _photosAllSizes['small'] = postUrl + 'media/?size=t';
      _photosAllSizes['medium'] = postUrl + 'media/?size=m';
      _photosAllSizes['large'] = postUrl + 'media/?size=l';
    } else {
      _photosAllSizes['small'] = postUrl + '/media/?size=t';
      _photosAllSizes['medium'] = postUrl + '/media/?size=m';
      _photosAllSizes['large'] = postUrl + '/media/?size=l';
    }    

    return _photosAllSizes;
  }
}